# pyadi-iio: [BETA] Analog Devices python interfaces for hardware with Industrial I/O drivers

## Still in beta and feedback is appreciated

[[Docs](http://analogdevicesinc.github.io/pyadi-iio/)]
[[Support](http://ez.analog.com)]
[[Wiki](https://wiki.analog.com/resources/tools-software/linux-software/pyadi-iio)]

### Currently supported hardware
- AD936X (Pluto, FMComms, ADRV936X)
- AD9371

### Dependencies
- libiio with python bindings
- numpy

### Installing from source
```
tcollins@jeeves:~$ git clone https://github.com/analogdevicesinc/pyadi-iio.git
tcollins@jeeves:~$ cd pyadi-iio
tcollins@jeeves:~$ (sudo) python setup.py install
```
### Installing from pip

```
tcollins@jeeves:~$ (sudo) pip install pyadi-iio
```
